summaryrefslogtreecommitdiffstats
path: root/tests/mocks
diff options
context:
space:
mode:
authordchill42 <dchill42@gmail.com>2012-08-28 05:59:31 +0200
committerdchill42 <dchill42@gmail.com>2012-08-28 05:59:31 +0200
commit6030719346e9b0eb0e0ea99c679cadeb1fe4afde (patch)
tree240c74ed9cdddabe4502a58ed37469c213107d1d /tests/mocks
parent2d5c209943ef1e2644504e8d5cb32d3d66b45632 (diff)
Improved VFS usage in Loader and Config units, added Loader driver test, and moved config load testing to Config unit
Signed-off-by: dchill42 <dchill42@gmail.com>
Diffstat (limited to 'tests/mocks')
-rw-r--r--tests/mocks/core/loader.php32
1 files changed, 18 insertions, 14 deletions
diff --git a/tests/mocks/core/loader.php b/tests/mocks/core/loader.php
index 53d88d55b..e28650dba 100644
--- a/tests/mocks/core/loader.php
+++ b/tests/mocks/core/loader.php
@@ -5,27 +5,31 @@ class Mock_Core_Loader extends CI_Loader {
/**
* Since we use paths to load up models, views, etc, we need the ability to
* mock up the file system so when core tests are run, we aren't mucking
* in the application directory. this will give finer grained control over
* these tests. So yeah, while this looks odd, I need to overwrite protected
* class vars in the loader. So here we go...
*
* @covers CI_Loader::__construct()
*/
public function __construct()
{
- vfsStreamWrapper::register();
- vfsStreamWrapper::setRoot(new vfsStreamDirectory('application'));
+ // Create VFS tree of loader locations
+ $this->root = vfsStream::setup();
+ $this->app_root = vfsStream::newDirectory('application')->at($this->root);
+ $this->base_root = vfsStream::newDirectory('system')->at($this->root);
- $this->models_dir = vfsStream::newDirectory('models')->at(vfsStreamWrapper::getRoot());
- $this->libs_dir = vfsStream::newDirectory('libraries')->at(vfsStreamWrapper::getRoot());
- $this->helpers_dir = vfsStream::newDirectory('helpers')->at(vfsStreamWrapper::getRoot());
- $this->views_dir = vfsStream::newDirectory('views')->at(vfsStreamWrapper::getRoot());
+ // Get VFS app and base path URLs
+ $this->app_path = vfsStream::url('application').'/';
+ $this->base_path = vfsStream::url('system').'/';
+ // Set loader paths with VFS URLs
$this->_ci_ob_level = ob_get_level();
- $this->_ci_library_paths = array(vfsStream::url('application').'/', BASEPATH);
- $this->_ci_helper_paths = array(vfsStream::url('application').'/', BASEPATH);
- $this->_ci_model_paths = array(vfsStream::url('application').'/');
- $this->_ci_view_paths = array(vfsStream::url('application').'/views/' => TRUE);
+ $this->_ci_library_paths = array($this->app_path, $this->base_path);
+ $this->_ci_helper_paths = array($this->app_path, $this->base_path);
+ $this->_ci_model_paths = array($this->app_path);
+ $this->_ci_view_paths = array($this->app_path.'views/' => TRUE);
}
-} \ No newline at end of file
+}
@@ -5,27 +5,31 @@ class Mock_Core_Loader extends CI_Loader {
* Since we use paths to load up models, views, etc, we need the ability to
* mock up the file system so when core tests are run, we aren't mucking
- * in the application directory. this will give finer grained control over
- * these tests. So yeah, while this looks odd, I need to overwrite protected
- * class vars in the loader. So here we go...
+ * in the application directory. This will give finer grained control over
+ * these tests. Also, by mocking the system directory, we eliminate dependency
+ * on any other classes so errors in libraries, helpers, etc. don't give false
+ * negatives for the actual loading process. So yeah, while this looks odd,
+ * I need to overwrite protected class vars in the loader. So here we go...
*
* @covers CI_Loader::__construct()